=============
Random Arrays
=============

.. currentmodule:: pynsn


NSNFactory
==========

.. autosummary::
    :toctree: api/

    NSNFactory
    init_random_generator


.. autoclass:: pynsn.NSNFactory
   :members:
   :show-inheritance:
   :undoc-members:

.. autofunction:: pynsn.init_random_generator
